<?php

namespace Drupal\switch_theme\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Database\Connection;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Switchtheme controller.
 */
class SwitchthemeController extends ControllerBase {
  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database')
    );
  }

  /**
   * Construct
   *
   * @param \Drupal\Core\Database\Connection $databaseConnection
   * 
   * @return void
   */
  public function __construct(Connection $connection) {
    $this->connection = $connection;
  }

  /**
   * Overview
   *
   * @return array
   */
  public function overview() {
    $rows = [];
    
    $header = [
      [
        'data' => $this->t('ID'),
        'field' => 'st.id',
        'class' => [RESPONSIVE_PRIORITY_MEDIUM],
      ],
      [
        'data' => $this->t('Name'),
        'field' => 'st.name',
        'class' => [RESPONSIVE_PRIORITY_MEDIUM],
      ],
      [
        'data' => $this->t('Operations'),
        'class' => [RESPONSIVE_PRIORITY_LOW],
      ],
    ];

    $query = $this->connection->select('switch_theme', 'st')
      ->extend('\Drupal\Core\Database\Query\PagerSelectExtender')
      ->extend('\Drupal\Core\Database\Query\TableSortExtender');
    $query->fields('st', [
      'id',
      'name'
    ]);
    
    $items = $query
      ->limit(50)
      ->orderByHeader($header)
      ->execute();

    foreach ($items as $item) {
      /**
       * Re-initialized links array for each row
       */
      $links = [];
      
      /**
       * The row information displayed for the current user
       */
      $row = [
        $item->id,
        $item->name
      ];

      /** 
       * Fill OPERATIONS links
       */
      $links['edit'] = [
        'title' => $this->t('Edit'),
        'url'   => Url::fromRoute('switch_theme.edit', ['id' => $item->id]),
      ];

      $links['delete'] = [
        'title' => $this->t('Delete'),
        'url'   => Url::fromRoute('switch_theme.delete', ['id' => $item->id]),
      ];

      $row[] = [
        'data' => [
          '#type'   => 'operations',
          '#links'  => $links,
        ],
      ];

      $rows[] = $row;
    }
    
    $build['switch_theme_table'] = [
      '#type' 	=> 'table',
      '#header' => $header,
      '#rows' 	=> $rows,
      '#empty' 	=> $this->t('No switch theme available.'),
    ];
    $build['switch_theme_pager'] = ['#type' => 'pager'];

    return $build;
  }
}
