<?php

namespace Drupal\switch_theme\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Url;
use Drupal\Core\Database\Connection;

class DeleteForm extends ConfirmFormBase {
    /**
     * The database connection.
     *
     * @var \Drupal\Core\Database\Connection
     */
    protected $connection;
    
    /**
     * Item id to delete
     *
     * @var int
     */
    protected $id = null;
    
    /**
     * Construct
     *
     * @param \Drupal\Core\Database\Connection $connection The database connection
     */
    public function __construct(Connection $connection) {
        $this->connection = $connection;
    }
    
    /**
     * Create
     *
     * @param ContainerInterface $container
     */
    public static function create(ContainerInterface $container) {
        return new static($container->get('database'));
    }
    
    /**
     * {@inheritdoc}
     */
    public function getFormId() {
        return 'switch_theme_admin';
    }
    
    /**
     * {@inheritdoc}
     */
    public function getQuestion() {
        return $this->t('Do you really want to remove this switch theme ?');
    }
    
    /**
     * {@inheritdoc}
     */
    public function getCancelUrl() {
        return new Url('switch_theme.overview');
    }
    
    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state, $id = null) {
        $this->id = $id;
        return parent::buildForm($form, $form_state);
    }
    
    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state) {
        try {
            $this->connection->delete('switch_theme')->condition('id', $this->id)->execute();
            $this->connection->delete('switch_theme_role')->condition('switch_theme_id', $this->id, "=")->execute();
            $this->connection->delete('switch_theme_pattern')->condition('switch_theme_id', $this->id, "=")->execute();
            $this->connection->delete('switch_theme_theme')->condition('switch_theme_id', $this->id, "=")->execute();

            $this->messenger()->addMessage($this->t('The switch theme has been deleted'));
        } catch (\Exception $e) {
            $this->messenger()->addMessage($e->getMessage(), 'error');
        }
       
        $response = Url::fromRoute('switch_theme.overview');
        $form_state->setRedirectUrl($response);
    }
}
